function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/*
Copyright (c) 2018 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import React from 'react';
import { shallow } from 'enzyme';
import { StatefulContainer as StatefulPopoverContainer } from '../../popover/index.js';
import { Tooltip, StatefulTooltip, PLACEMENT, TRIGGER_TYPE } from '../index.js';
import baseDefaultProps from '../default-props.js';

function withoutChildren(props) {
  var shallowCopy = _objectSpread({}, props);

  delete shallowCopy.children;
  return shallowCopy;
}

describe('StatefulTooltip', function () {
  test('basic render', function () {
    function CustomBody() {
      return React.createElement("span", null);
    }

    var props = {
      overrides: {
        Body: CustomBody
      },
      content: jest.fn(),
      initialState: {
        isOpen: true
      },
      onMouseEnterDelay: 100,
      onMouseLeaveDelay: 200,
      onClose: jest.fn(),
      onOpen: jest.fn(),
      placement: PLACEMENT.topLeft,
      showArrow: true,
      stateReducer: jest.fn(),
      triggerType: TRIGGER_TYPE.hover
    };
    var component = shallow(React.createElement(StatefulTooltip, props, React.createElement("span", null, "Hover me"))); // Should first render a stateful tooltip container

    expect(component).toMatchSnapshot('renders <StatefulContainer/>'); // Should delegate to stateful popover container

    var dive = component.dive();
    expect(dive.type()).toEqual(StatefulPopoverContainer);
    expect(withoutChildren(dive.props())).toEqual(_objectSpread({}, baseDefaultProps, props, {
      dismissOnClickOutside: true,
      dismissOnEsc: true,
      ignoreBoundary: false
    })); // But ultimately render a tooltip

    dive = dive.dive();
    expect(dive.type()).toEqual(Tooltip);
    expect(dive).toMatchSnapshot('renders <Tooltip/>');
  });
});